summaryrefslogtreecommitdiffstats
path: root/templates/native/etc/config.cmake
diff options
context:
space:
mode:
authorRomain Forlot <romain.forlot@iot.bzh>2017-05-09 13:20:38 +0200
committerRomain Forlot <romain.forlot@iot.bzh>2017-05-09 13:20:38 +0200
commit9ea81dbd25d509cbe88de0702bed54020180f979 (patch)
treea0ee0bbdc777459723a2c1291b8b563a2938e2b5 /templates/native/etc/config.cmake
parent0a189f7f28b382e57b642932f820f5ee818aba9f (diff)
Update template with references.
Change-Id: Ic575adc4c8815f41a02c32d9835332cc2608d513 Signed-off-by: Romain Forlot <romain.forlot@iot.bzh>
Diffstat (limited to 'templates/native/etc/config.cmake')
-rw-r--r--templates/native/etc/config.cmake44
1 files changed, 30 insertions, 14 deletions
diff --git a/templates/native/etc/config.cmake b/templates/native/etc/config.cmake
index db69675..0507853 100644
--- a/templates/native/etc/config.cmake
+++ b/templates/native/etc/config.cmake
@@ -31,27 +31,20 @@ set(PROJECT_ICON "icon.png")
# ----------------------------------
set(CMAKE_BUILD_TYPE "DEBUG")
# Compiler selection if needed. Overload the detected compiler.
# -----------------------------------------------
-#set(CMAKE_C_COMPILER "gcc")
-#set(CMAKE_CXX_COMPILER "g++")
+set (gcc_minimal_version 4.9)
# PKG_CONFIG required packages
# -----------------------------
-set (PKG_REQUIRED_LIST
+set (PKG_REQUIRED_LIST
json-c
- libsystemd
- libafbwsc
afb-daemon
)
# Static constante definition
# -----------------------------
-add_compile_options(
- ${libafbwsc_CFLAGS}
- ${json-c_CFLAGS}
- ${libsystemd_CFLAGS}
-)
+add_compile_options()
# LANG Specific compile flags set for all build types
set(CMAKE_C_FLAGS "")
@@ -60,7 +53,7 @@ set(CMAKE_CXX_FLAGS "")
# Print a helper message when every thing is finished
# ----------------------------------------------------
#set(CLOSING_MESSAGE "")
-
+#set(WIDGET_MESSAGE "Install widget file using in the target : afm-util install ${PROJECT_NAME}.wgt")
# (BUG!!!) as PKG_CONFIG_PATH does not work [should be an env variable]
# ---------------------------------------------------------------------
@@ -82,12 +75,35 @@ set(LD_LIBRARY_PATH ${CMAKE_INSTALL_PREFIX}/lib64 ${CMAKE_INSTALL_PREFIX}/lib)
# Optional force binding installation
# ------------------------------------
-set(BINDINGS_INSTALL_PREFIX /opt )
+# set(BINDINGS_INSTALL_PREFIX PrefixPath )
# Optional force widget prefix generation
-# ---------------------------------------
+# ------------------------------------------------
# set(WIDGET_PREFIX DestinationPath)
+# Optional Widget entry point file.
+# ---------------------------------------------------------
+ # This is the file that will be executed, loaded,...
+# at launch time by the application framework
+
+# set(WIDGET_ENTRY_POINT EntryPoint_Path)
+
+# Optional Widget Mimetype specification
+# --------------------------------------------------
+# Choose between :
+# - application/x-executable
+# - application/vnd.agl.url
+# - application/vnd.agl.service
+# - application/vnd.agl.native
+# - text/vnd.qt.qml
+# - text/html
+# - application/vnd.agl.qml
+# - application/vnd.agl.qml.hybrid
+# - application/vnd.agl.html.hybrid
+#
+# set(WIDGET_TYPE MimeType)
+
# Optional force binding Linking flag
# ------------------------------------
# set(BINDINGS_LINK_FLAG LinkOptions )
+
@@ -31,27 +31,20 @@ set(PROJECT_ICON "icon.png")
# ----------------------------------
set(CMAKE_BUILD_TYPE "DEBUG")
-# Compiler selection if needed. Overload the detected compiler.
+# Compiler selection if needed. Impose a minimal version.
# -----------------------------------------------